==> request-tracker4_4.4.4%2Bdfsg.orig-third-party-source.tar.gz: rt-4.4.4/devel/third-party/ckeditor-src/plugins/table/lang/pt.js <==
﻿/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'table', 'pt', {
	border: 'Tamanho do contorno',
	caption: 'Legenda',
	cell: {
		menu: 'Célula',
		insertBefore: 'Inserir célula antes',
		insertAfter: 'Inserir célula depois',
		deleteCell: 'Apagar Células',
		merge: 'Unir Células',
		mergeRight: 'Unir à Direita',
		mergeDown: 'Fundir abaixo',
		splitHorizontal: 'Dividir célula horizontalmente',
		splitVertical: 'Dividir célula verticalmente',
		title: 'Propriedades da célula',
		cellType: 'Tipo de célula',
		rowSpan: 'Filas na Célula',
		colSpan: 'Colunas na Célula',
		wordWrap: 'Moldar texto',
		hAlign: 'Alinhamento Horizontal',
		vAlign: 'Alinhamento Vertical',
		alignBaseline: 'Base',
		bgColor: 'Cor de Fundo',
		borderColor: 'Cor da Margem',
		data: 'Dados',
		header: 'Cabeçalho',
		yes: 'Sim',
		no: 'Não',
		invalidWidth: 'A largura da célula deve ser um número.',
		invalidHeight: 'A altura da célula deve ser um número.',
		invalidRowSpan: 'As filas da célula deve ter um número inteiro.',
		invalidColSpan: 'As colunas da célula deve ter um número inteiro.',
		chooseColor: 'Escolher'
	},
	cellPad: 'Espaço interior',
	cellSpace: 'Espaçamento de célula',
	column: {
		menu: 'Coluna',
		insertBefore: 'Inserir Coluna Antes',
		insertAfter: 'Inserir coluna depois',
		deleteColumn: 'Apagar colunas'
	},
	columns: 'Colunas',
	deleteTable: 'Apagar tabela',
	headers: 'Cabeçalhos',
	headersBoth: 'Ambos',
	headersColumn: 'Primeira coluna',
	headersNone: 'Nenhum',
	headersRow: 'Primeira linha',
	invalidBorder: 'O tamanho da margem tem de ser um número.',
	invalidCellPadding: 'A criação do espaço na célula deve ser um número positivo.',
	invalidCellSpacing: 'O espaçamento da célula deve ser um número positivo.',
	invalidCols: 'O número de colunas tem de ser um número maior que 0.',
	invalidHeight: 'A altura da tabela tem de ser um número.',
	invalidRows: 'O número de linhas tem de ser maior que 0.',
	invalidWidth: 'A largura da tabela tem de ser um número.',
	menu: 'Propriedades da Tabela',
	row: {
		menu: 'Linha',
		insertBefore: 'Inserir linha antes',
		insertAfter: 'Inserir linha depois',
		deleteRow: 'Apagar linhas'
	},
	rows: 'Linhas',
	summary: 'Sumário',
	title: 'Propriedades da Tabela',
	toolbar: 'Tabela',
	widthPc: 'percentagem',
	widthPx: 'pontos',
	widthUnit: 'unidade da largura'
} );

==> request-tracker5_5.0.3%2Bdfsg.orig-third-party-source.tar.gz: rt-5.0.3/devel/third-party/ckeditor-src/plugins/table/lang/pt.js <==
/*
Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'table', 'pt', {
	border: 'Tamanho do contorno',
	caption: 'Legenda',
	cell: {
		menu: 'Célula',
		insertBefore: 'Inserir célula antes',
		insertAfter: 'Inserir célula depois',
		deleteCell: 'Apagar células',
		merge: 'Unir células',
		mergeRight: 'Unir à direita',
		mergeDown: 'Fundir abaixo',
		splitHorizontal: 'Dividir célula horizontalmente',
		splitVertical: 'Dividir célula verticalmente',
		title: 'Propriedades da célula',
		cellType: 'Tipo de célula',
		rowSpan: 'Linhas na célula',
		colSpan: 'Colunas na célula',
		wordWrap: 'Moldar texto',
		hAlign: 'Alinhamento horizontal',
		vAlign: 'Alinhamento vertical',
		alignBaseline: 'Linha base',
		bgColor: 'Cor de fundo',
		borderColor: 'Cor da margem',
		data: 'Dados',
		header: 'Cabeçalho',
		yes: 'Sim',
		no: 'Não',
		invalidWidth: 'A largura da célula deve ser um número.',
		invalidHeight: 'A altura da célula deve ser um número.',
		invalidRowSpan: 'As linhas da célula devem ser um número inteiro.',
		invalidColSpan: 'As colunas da célula devem ter um número inteiro.',
		chooseColor: 'Escolher'
	},
	cellPad: 'Espaço interior',
	cellSpace: 'Espaçamento de célula',
	column: {
		menu: 'Coluna',
		insertBefore: 'Inserir coluna antes',
		insertAfter: 'Inserir coluna depois',
		deleteColumn: 'Apagar colunas'
	},
	columns: 'Colunas',
	deleteTable: 'Apagar tabela',
	headers: 'Cabeçalhos',
	headersBoth: 'Ambos',
	headersColumn: 'Primeira coluna',
	headersNone: 'Nenhum',
	headersRow: 'Primeira linha',
	heightUnit: 'height unit', // MISSING
	invalidBorder: 'O tamanho da margem tem de ser um número.',
	invalidCellPadding: 'A criação do espaço na célula deve ser um número positivo.',
	invalidCellSpacing: 'O espaçamento da célula deve ser um número positivo.',
	invalidCols: 'O número de colunas tem de ser um número maior que 0.',
	invalidHeight: 'A altura da tabela tem de ser um número.',
	invalidRows: 'O número de linhas tem de ser maior que 0.',
	invalidWidth: 'A largura da tabela tem de ser um número.',
	menu: 'Propriedades da tabela',
	row: {
		menu: 'Linha',
		insertBefore: 'Inserir linha antes',
		insertAfter: 'Inserir linha depois',
		deleteRow: 'Apagar linhas'
	},
	rows: 'Linhas',
	summary: 'Resumo',
	title: 'Propriedades da tabela',
	toolbar: 'Tabela',
	widthPc: 'percentagem',
	widthPx: 'píxeis',
	widthUnit: 'unidade da largura'
} );
